@@ -3,10 +3,8 @@
 use strict;
 use warnings;
 package Alien::Sodium;
-BEGIN {
-  $Alien::Sodium::AUTHORITY = 'cpan:AJGB';
-}
-$Alien::Sodium::VERSION = '0.01';
+our $AUTHORITY = 'cpan:AJGB';
+$Alien::Sodium::VERSION = '1.0.3.0';
 use parent 'Alien::Base';
 
 1;
@@ -15,7 +13,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -23,7 +21,7 @@ Alien::Sodium - Install and make available libsodium library
 
 =head1 VERSION
 
-version 0.01
+version 1.0.3.0
 
 =head1 SYNOPSIS
 
@@ -34,13 +32,13 @@ version 0.01
 
 =head1 DESCRIPTION
 
-Alien::Sodium installs the C library C<libsodium> version v0.4.5 (2014-02-03).
+Alien::Sodium installs the C library C<libsodium> version 1.0.3 released on May 9, 2015.
 
 =head1 SEE ALSO
 
 =over 4
 
-=item * L<https://github.com/jedisct1/libsodium>
+=item * L<libsodium|https://github.com/jedisct1/libsodium>
 
 =back
 
@@ -50,7 +48,7 @@ Alex J. G. Burzyński <ajgb@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Alex J. G. Burzyński <ajgb@cpan.org>.
+This software is copyright (c) 2015 by Alex J. G. Burzyński <ajgb@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
